[Phpmyadmin-git] [SCM] phpMyAdmin branch, master, updated. RELEASE_3_3_3-4489-gcaa9844

Marc Delisle lem9 at users.sourceforge.net
Mon May 31 20:33:31 CEST 2010


The branch, master has been updated
       via  caa98445d818b85f0fbec0e76c64b5774b32ca22 (commit)
      from  5a3ebdec93d2c363f65a20b5db13e7d64e8eb861 (commit)


- Log -----------------------------------------------------------------
commit caa98445d818b85f0fbec0e76c64b5774b32ca22
Author: Marc Delisle <marc at infomarc.info>
Date:   Mon May 31 14:33:21 2010 -0400

    conform to relational terminology regarding columns and rows

-----------------------------------------------------------------------

Summary of changes:
 Documentation.html                                 |  170 ++++++++++----------
 db_datadict.php                                    |    6 +-
 db_printview.php                                   |    2 +-
 db_qbe.php                                         |    6 +-
 db_search.php                                      |    2 +-
 js/messages.php                                    |    2 +-
 libraries/Index.class.php                          |    2 +-
 libraries/db_structure.lib.php                     |    4 +-
 libraries/display_create_table.lib.php             |    4 +-
 libraries/display_export.lib.php                   |    2 +-
 libraries/display_import.lib.php                   |    2 +-
 libraries/display_tbl.lib.php                      |    4 +-
 libraries/export/csv.php                           |   10 +-
 libraries/export/excel.php                         |    4 +-
 libraries/export/htmlword.php                      |    4 +-
 libraries/export/latex.php                         |    4 +-
 libraries/export/ods.php                           |    2 +-
 libraries/export/odt.php                           |    4 +-
 libraries/export/sql.php                           |    2 +-
 libraries/export/texytext.php                      |    4 +-
 libraries/export/xls.php                           |    2 +-
 libraries/export/xlsx.php                          |    2 +-
 libraries/import/csv.php                           |   14 +-
 libraries/import/ldi.php                           |    6 +-
 libraries/sql_query_form.lib.php                   |    2 +-
 libraries/tbl_properties.inc.php                   |   10 +-
 .../application_octetstream__download.inc.php      |    2 +-
 .../transformations/text_plain__dateformat.inc.php |    2 +-
 .../transformations/text_plain__external.inc.php   |    2 +-
 .../transformations/text_plain__formatted.inc.php  |    2 +-
 .../transformations/text_plain__imagelink.inc.php  |    2 +-
 libraries/transformations/text_plain__link.inc.php |    2 +-
 pdf_schema.php                                     |    4 +-
 pmd_general.php                                    |    2 +-
 pmd_help.php                                       |    2 +-
 setup/lib/messages.inc.php                         |   18 +-
 tbl_alter.php                                      |    4 +-
 tbl_change.php                                     |    4 +-
 tbl_indexes.php                                    |    2 +-
 tbl_printview.php                                  |    2 +-
 tbl_relation.php                                   |    4 +-
 tbl_select.php                                     |    4 +-
 tbl_structure.php                                  |   10 +-
 tbl_tracking.php                                   |    4 +-
 44 files changed, 176 insertions(+), 172 deletions(-)

diff --git a/Documentation.html b/Documentation.html
index 3a97d27..659cd68 100644
--- a/Documentation.html
+++ b/Documentation.html
@@ -101,8 +101,8 @@ vim: expandtab ts=4 sw=4 sts=4 tw=78
 
 <h3>Currently phpMyAdmin can:</h3>
 
-<ul><li>browse and drop databases, tables, views, fields and indexes</li>
-    <li>create, copy, drop, rename and alter databases, tables, fields and
+<ul><li>browse and drop databases, tables, views, columns and indexes</li>
+    <li>create, copy, drop, rename and alter databases, tables, columns and
         indexes</li>
     <li>maintenance server, databases and tables, with proposals on server
         configuration</li>
@@ -328,7 +328,7 @@ rm -rf config                      # remove not needed directory
 <p> For a whole set of new features (bookmarks, comments,
     <abbr title="structured query language">SQL</abbr>-history,
     tracking mechanism,
-    <abbr title="Portable Document Format">PDF</abbr>-generation, field contents
+    <abbr title="Portable Document Format">PDF</abbr>-generation, column contents
     transformation, etc.) you need to create a set of special tables. Those
     tables can be located in your own database, or in a central database for a
     multi-user installation (this database would then be accessed by the
@@ -893,17 +893,17 @@ since this link provides funding for phpMyAdmin.
         <span id="cfg_Servers_relation">$cfg['Servers'][$i]['relation']</span> string
     </dt>
     <dd>Since release 2.2.4 you can describe, in a special 'relation' table,
-        which field is a key in another table (a foreign key). phpMyAdmin
+        which column is a key in another table (a foreign key). phpMyAdmin
         currently uses this to
         <ul><li>make clickable, when you browse the master table, the data values
                 that point to the foreign table;</li>
-            <li>display in an optional tool-tip the "display field"
+            <li>display in an optional tool-tip the "display column"
                 when browsing the master table, if you move the mouse to a column
                 containing a foreign key (use also the 'table_info' table);<br />
                 (see <a href="#faqdisplay"><abbr title="Frequently Asked Questions">
                 FAQ</abbr> 6.7</a>)</li>
             <li>in edit/insert mode, display a drop-down list of possible foreign
-                keys (key value and "display field" are shown)<br />
+                keys (key value and "display column" are shown)<br />
                 (see <a href="#faq6_21"><abbr title="Frequently Asked Questions">
                 FAQ</abbr> 6.21</a>)</li>
             <li>display links on the table properties page, to check referential
@@ -925,12 +925,13 @@ since this link provides funding for phpMyAdmin.
                 <tt>$cfg['Servers'][$i]['relation']</tt></li>
             <li>now as normal user open phpMyAdmin and for each one of your
                 tables where you want to use this feature, click
-                "Structure/Relation view/" and choose foreign fields.
+                "Structure/Relation view/" and choose foreign
+                columns.
                 </li>
         </ul>
 
         Please note that in the current version, <tt>master_db</tt>
-        must be the same as <tt>foreign_db</tt>. Those fields have been put in
+        must be the same as <tt>foreign_db</tt>. Those columns have been put in
         future development of the cross-db relations.
     </dd>
 
@@ -939,7 +940,7 @@ since this link provides funding for phpMyAdmin.
     </dt>
     <dd>
         Since release 2.3.0 you can describe, in a special 'table_info'
-        table, which field is to be displayed as a tool-tip when moving the
+        table, which column is to be displayed as a tool-tip when moving the
         cursor over the corresponding key.<br />
         This configuration variable will hold the name of this special
         table. To allow the usage of this functionality:
@@ -947,10 +948,10 @@ since this link provides funding for phpMyAdmin.
             <li>put the table name in
                 <tt>$cfg['Servers'][$i]['table_info']</tt></li>
             <li>then for each table where you want to use this feature,
-                click "Structure/Relation view/Choose field to display"
-                to choose the field.</li>
+                click "Structure/Relation view/Choose column to display"
+                to choose the column.</li>
         </ul>
-        Usage tip: <a href="#faqdisplay">Display field</a>.
+        Usage tip: <a href="#faqdisplay">Display column</a>.
     </dd>
     <dt id="table_coords">
         <span id="cfg_Servers_table_coords">$cfg['Servers'][$i]['table_coords']</span> string<br />
@@ -997,7 +998,7 @@ since this link provides funding for phpMyAdmin.
         based on the following table structure. See <a href="#transformations">
         Transformations</a> for further information. To use the
         MIME-transformation system, your column_info table has to have the three
-        new fields 'mimetype', 'transformation', 'transformation_options'.
+        new columns 'mimetype', 'transformation', 'transformation_options'.
         <br /><br />
 
         To allow the usage of this functionality:
@@ -1154,7 +1155,7 @@ CREATE DATABASE,ALTER DATABASE,DROP DATABASE</pre>
     <dt><span id="cfg_Servers_verbose_check">$cfg['Servers'][$i]['verbose_check']</span> boolean
     </dt>
     <dd>Because release 2.5.0 introduced the new MIME-transformation support, the
-        column_info table got enhanced with three new fields. If the above variable
+        column_info table got enhanced with three new columns. If the above variable
         is set to <tt>TRUE</tt> (default) phpMyAdmin will check if you have the
         latest table structure available. If not, it will emit a warning to the
         superuser.<br /><br />
@@ -1531,9 +1532,9 @@ CREATE DATABASE,ALTER DATABASE,DROP DATABASE</pre>
         contains more rows, "Previous" and "Next" links will be shown.</dd>
 
     <dt id="cfg_Order">$cfg['Order'] string [<tt>DESC</tt>|<tt>ASC</tt>|<tt>SMART</tt>]</dt>
-    <dd>Defines whether fields are displayed in ascending (<tt>ASC</tt>) order,
+    <dd>Defines whether columns are displayed in ascending (<tt>ASC</tt>) order,
         in descending (<tt>DESC</tt>) order or in a "smart"
-        (<tt>SMART</tt>) order - I.E. descending order for fields of type TIME,
+        (<tt>SMART</tt>) order - I.E. descending order for columns of type TIME,
         DATE, DATETIME and TIMESTAMP, ascending order else- by default.</dd>
 
     <dt id="cfg_DisplayBinaryAsHex">$cfg['DisplayBinaryAsHex'] boolean </dt>
@@ -1541,12 +1542,12 @@ CREATE DATABASE,ALTER DATABASE,DROP DATABASE</pre>
     option is ticked by default.</dd>
 
     <dt id="cfg_ProtectBinary">$cfg['ProtectBinary'] boolean or string</dt>
-    <dd>Defines whether <tt>BLOB</tt> or <tt>BINARY</tt> fields are protected
+    <dd>Defines whether <tt>BLOB</tt> or <tt>BINARY</tt> columns are protected
         from editing when browsing a table's content. Valid values are:
-        <ul><li><tt>FALSE</tt> to allow editing of all fields;</li>
-            <li><tt>'blob'</tt> to allow editing of all fields except <tt>BLOBS</tt>;</li>
+        <ul><li><tt>FALSE</tt> to allow editing of all columns;</li>
+            <li><tt>'blob'</tt> to allow editing of all columns except <tt>BLOBS</tt>;</li>
             <li><tt>'all'</tt> to disallow editing of all <tt>BINARY</tt> or
-                <tt>BLOB</tt> fields.</li>
+                <tt>BLOB</tt> columns.</li>
         </ul>
     </dd>
 
@@ -1564,10 +1565,10 @@ CREATE DATABASE,ALTER DATABASE,DROP DATABASE</pre>
 
     <dt id="cfg_CharEditing">$cfg['CharEditing'] string</dt>
     <dd>Defines which type of editing controls should be used for CHAR and
-        VARCHAR fields. Possible values are:
-        <ul><li>input - this allows to limit size of text to size of field in
-                MySQL, but has problems with newlines in fields</li>
-            <li>textarea - no problems with newlines in fields, but also no
+        VARCHAR columns. Possible values are:
+        <ul><li>input - this allows to limit size of text to size of columns in
+                MySQL, but has problems with newlines in columns</li>
+            <li>textarea - no problems with newlines in columns, but also no
                 length limitations</li>
         </ul>
         Default is old behavior so input.</dd>
@@ -1850,7 +1851,7 @@ $cfg['TrustedProxies'] =
 
     <dt><span id="cfg_LongtextDoubleTextarea">$cfg['LongtextDoubleTextarea'] </span>boolean
     </dt>
-    <dd>Defines whether textarea for LONGTEXT fields should have double size.</dd>
+    <dd>Defines whether textarea for LONGTEXT columns should have double size.</dd>
 
     <dt><span id="cfg_TextareaAutoSelect">$cfg['TextareaAutoSelect'] </span>boolean
     </dt>
@@ -1863,7 +1864,7 @@ $cfg['TrustedProxies'] =
         editing.</dd>
 
     <dt id="cfg_LimitChars">$cfg['LimitChars'] integer</dt>
-    <dd>Maximum number of characters showen in any non-numeric field on browse view.
+    <dd>Maximum number of characters showen in any non-numeric column on browse view.
         Can be turned off by a toggle button on the browse page.</dd>
 
     <dt><span id="cfg_ModifyDeleteAtLeft">$cfg['ModifyDeleteAtLeft'] </span>boolean
@@ -1879,7 +1880,7 @@ $cfg['TrustedProxies'] =
     <dd>There are 3 display modes: horizontal, horizontalflipped and vertical.
         Define which one is displayed by default. The first mode displays each
         row on a horizontal line, the second rotates the headers by 90
-        degrees, so you can use descriptive headers even though fields only
+        degrees, so you can use descriptive headers even though columns only
         contain small values and still print them out. The vertical mode sorts
         each row on a vertical lineup.
     </dd>
@@ -1903,9 +1904,9 @@ $cfg['TrustedProxies'] =
         'vertical' you can have each field lined up vertically beneath each
         other. You can save up a lot of place on the horizontal direction and
         no longer have to scroll. If you set this to integer, editing of fewer
-        columns will appear in 'vertical' mode, while editing of more fields
+        columns will appear in 'vertical' mode, while editing of more columns 
         still in 'horizontal' mode. This way you can still effectively edit
-        large number of fields, while having full view on few of them.</dd>
+        large number of columns, while having full view on few of them.</dd>
 
     <dt id="cfg_ShowBrowseComments">$cfg['ShowBrowseComments'] boolean<br />
         <span id="cfg_ShowPropertyComments">$cfg['ShowPropertyComments'] </span>boolean
@@ -1914,7 +1915,7 @@ $cfg['TrustedProxies'] =
         display of column comments in Browse or Property display. In browse
         mode, the comments are shown inside the header. In property mode,
         comments are displayed using a CSS-formatted dashed-line below the
-        name of the field. The comment is shown as a tool-tip for that field.
+        name of the column. The comment is shown as a tool-tip for that column.
     </dd>
 
     <dt id ="cfg_SQLQuery_Edit">$cfg['SQLQuery']['Edit'] boolean</dt>
@@ -2208,7 +2209,7 @@ setfacl -d -m "g:www-data:rwx" tmp
     </dt>
     <dd>Default queries that will be displayed in query boxes when user didn't
         specify any. Use %d for database name, %t for table name and %f for a
-        comma separated list of field names. Note that %t and %f are only
+        comma separated list of column names. Note that %t and %f are only
         applicable to <tt>$cfg['DefaultQueryTable']</tt>.</dd>
 
     <dt id="cfg_SQP_fmtType">$cfg['SQP']['fmtType'] string [<tt>html</tt>|<tt>none</tt>]</dt>
@@ -2319,7 +2320,7 @@ setfacl -d -m "g:www-data:rwx" tmp
         edit this.</dd>
 
     <dt id="cfg_AttributeTypes">$cfg['AttributeTypes'] array</dt>
-    <dd>Possible attributes for fields. In most cases you don't need to edit
+    <dd>Possible attributes for columns. In most cases you don't need to edit
         this.</dd>
 
     <dt id="cfg_Functions">$cfg['Functions'] array</dt>
@@ -2343,21 +2344,21 @@ setfacl -d -m "g:www-data:rwx" tmp
         in table.</dd>
 
     <dt id="cfg_NumOperators">$cfg['NumOperators'] array</dt>
-    <dd>Operators available for search operations on numeric and date fields.
+    <dd>Operators available for search operations on numeric and date columns.
     </dd>
 
     <dt id="cfg_TextOperators">$cfg['TextOperators'] array</dt>
-    <dd>Operators available for search operations on character fields.
+    <dd>Operators available for search operations on character columns.
         Note that we put <code>LIKE</code> by default instead of
         <code>LIKE %...%</code>, to avoid unintended performance problems
         in case of huge tables.</dd>
 
     <dt id="cfg_EnumOperators">$cfg['EnumOperators'] array</dt>
-    <dd>Operators available for search operations on enum fields.</dd>
+    <dd>Operators available for search operations on ENUM columns.</dd>
 
     <dt id="cfg_NullOperators">$cfg['NullOperators'] array</dt>
     <dd>Additional operators available for search operations when the
-        field can be null.</dd>
+        column can be null.</dd>
 
 </dl>
 
@@ -2375,14 +2376,14 @@ setfacl -d -m "g:www-data:rwx" tmp
     and the proper directives. Please see the <a href="#config">Configuration
     section</a> on how to do so.</p>
 
-<p> You can apply different transformations to the contents of each field. The
-    transformation will take the content of each field and transform it with
+<p> You can apply different transformations to the contents of each column. The
+    transformation will take the content of each column and transform it with
     certain rules defined in the selected transformation.</p>
 
-<p> Say you have a field 'filename' which contains a filename. Normally you would
+<p> Say you have a column 'filename' which contains a filename. Normally you would
     see in phpMyAdmin only this filename. Using transformations you can transform
     that filename into a HTML link, so you can click inside of the phpMyAdmin
-    structure on the field's link and will see the file displayed in a new browser
+    structure on the column's link and will see the file displayed in a new browser
     window. Using transformation options you can also specify strings to
     append/prepend to a string or the format you want the output stored in.</p>
 
@@ -2399,7 +2400,8 @@ setfacl -d -m "g:www-data:rwx" tmp
 
 <p> Go to your <i>tbl_structure.php</i> page (i.e. reached through
     clicking on the 'Structure' link for a table). There click on
-    "Change" (or change icon) and there you will see three new fields at
+    "Change" (or change icon) and there you will see three new
+    fields at
     the end of the line. They are called 'MIME-type', 'Browser transformation' and
     'Transformation options'.</p>
 
@@ -2455,7 +2457,7 @@ setfacl -d -m "g:www-data:rwx" tmp
 <p> One can, however, use empty mime-types and global transformations which should work
     for many mimetypes. You can also use transforms on a different mimetype they where built
     for, but pay attention to option usage as well as what the transformation does to your
-    field.</p>
+    column.</p>
 
 <p> There is a basic file called '<i>global.inc.php</i>'. This function can be included by
     any other transform function and provides some basic functions.</p>
@@ -2560,15 +2562,15 @@ setfacl -d -m "g:www-data:rwx" tmp
         you want to transform.</li>
     <li><b>$options</b> - Contains any user-passed options to a transform function
         as an array.</li>
-    <li><b>$meta</b> - Contains an object with field information to your column.
+    <li><b>$meta</b> - Contains an object with information about your column.
         The data is drawn from the output of the
         <a href="http://www.php.net/mysql_fetch_field">mysql_fetch_field()</a>
         function. This means, all object properties described on the
         <a href="http://www.php.net/mysql_fetch_field">manual page</a> are
-        available in this variable and can be used to transform a field accordingly
+        available in this variable and can be used to transform a column accordingly
         to unsigned/zerofill/not_null/... properties.<br />
         The $meta->mimetype variable contains the original MIME-type of the
-        field (i.e. 'text/plain', 'image/jpeg' etc.)</li>
+        column (i.e. 'text/plain', 'image/jpeg' etc.)</li>
 </ol>
 
 <p> Additionally you should also provide additional function to provide 
@@ -2768,11 +2770,11 @@ setfacl -d -m "g:www-data:rwx" tmp
     and try to increase it.</p>
 
 <h4 id="faq1_15">
-    <a href="#faq1_15">1.15 I have problems with <i>mysql.user</i> field names.</a>
+    <a href="#faq1_15">1.15 I have problems with <i>mysql.user</i> column names.</a>
 </h4>
 
-<p> In previous MySQL versions, the <tt>User</tt> and <tt>Password</tt> fields
-    were named <tt>user</tt> and <tt>password</tt>. Please modify your field
+<p> In previous MySQL versions, the <tt>User</tt> and <tt>Password</tt>columns 
+    were named <tt>user</tt> and <tt>password</tt>. Please modify your column 
     names to align with current standards.</p>
 
 <h4 id="faq1_16">
@@ -2900,7 +2902,7 @@ setfacl -d -m "g:www-data:rwx" tmp
 
 <h4 id="faq1_23">
     <a href="#faq1_23">1.23 I'm running MySQL on a Win32 machine. Each time I create
-    a new table the table and field names are changed to lowercase!</a></h4>
+    a new table the table and column names are changed to lowercase!</a></h4>
 
 <p> This happens because the MySQL directive <tt>lower_case_table_names</tt>
     defaults to 1 (<tt>ON</tt>) in the Win32 version of MySQL. You can change
@@ -2970,8 +2972,8 @@ setfacl -d -m "g:www-data:rwx" tmp
     available starting with MySQL 3.23.56 / 4.0.11-gamma.</p>
 
 <h4 id="faq1_29">
-    <a href="#faq1_29">1.29 When I create a table or modify a field, I get an error
-    and the fields are duplicated.</a></h4>
+    <a href="#faq1_29">1.29 When I create a table or modify a column, I get an error
+    and the columns are duplicated.</a></h4>
 
 <p> It is possible to configure Apache in such a way that PHP has problems
     interpreting .php files.</p>
@@ -3101,7 +3103,7 @@ RewriteRule .* - [E=REMOTE_USER:%{HTTP:Authorization},L]
 <p>
     Suhosin configuration might lead to malfunction in some cases and it can
     not be fully avoided as phpMyAdmin is kind of application which needs to
-    transfer big amounts of fields in single HTTP request, what is something
+    transfer big amounts of columns in single HTTP request, what is something
     what Suhosin tries to prevent. Generally all
     <code>suhosin.request.*</code>, <code>suhosin.post.*</code> and
     <code>suhosin.get.*</code> directives can have negative effect on
@@ -3430,13 +3432,13 @@ have either the <a href="http://pecl.php.net/package/APC">APC</a> extension
     <a href="#faq3_6">3.6 What is currently not supported in phpMyAdmin about InnoDB?</a></h4>
 
 <p> In Relation view, being able to choose a table in another database,
-    or having more than one index field in the foreign key.<br /><br/>
+    or having more than one index column in the foreign key.<br /><br/>
     In Query-by-example (Query), automatic generation of the query
     LEFT JOIN from the foreign table.<br /><br/>
 </p>
 
 <h4 id="faq3_7">
-    <a href="#faq3_7">3.7 I have table with many (100+) fields and when I try to browse table
+    <a href="#faq3_7">3.7 I have table with many (100+) columns and when I try to browse table
     I get series of errors like "Warning: unable to parse url". How
     can this be fixed?</a></h4>
 <p>
@@ -3447,7 +3449,7 @@ have either the <a href="http://pecl.php.net/package/APC">APC</a> extension
 </p>
 
 <h4 id="faq3_8">
-    <a href="#faq3_8">3.8 I cannot use (clickable) HTML-forms in fields where I put
+    <a href="#faq3_8">3.8 I cannot use (clickable) HTML-forms in columns where I put
     a MIME-Transformation onto!</a></h4>
 
 <p> Due to a surrounding form-container (for multi-row delete checkboxes), no
@@ -3696,14 +3698,14 @@ $cfg['Servers'][$i]['AllowDeny']['rules'] = array(
 
 <h4 id="faq5_1">
     <a href="#faq5_1">5.1 I get an out of memory error, and my controls are non-functional,
-    when trying to create a table with more than 14 fields.
+    when trying to create a table with more than 14 columns.
 </a></h4>
 <p>
     We could reproduce this problem only under Win98/98SE. Testing under
-    WinNT4 or Win2K, we could easily create more than 60 fields.
+    WinNT4 or Win2K, we could easily create more than 60 columns.
     <br />
-    A workaround is to create a smaller number of fields, then come back to
-    your table properties and add the other fields.
+    A workaround is to create a smaller number of columns, then come back to
+    your table properties and add the other columns.
 </p>
 
 <h4 id="faq5_2">
@@ -3751,7 +3753,8 @@ $cfg['Servers'][$i]['AllowDeny']['rules'] = array(
 
 <h4 id="faq5_6">
     <a href="#faq5_6">5.6 In Internet Explorer 5.0, 5.5 or 6.0, I get an error (like "Page not found")
-    when trying to modify a row in a table with many fields, or with a text field
+    when trying to modify a row in a table with many columns, or with a text
+    column 
 </a></h4>
 <p>
     Your table neither have a primary key nor an unique one, so we must use a
@@ -3871,7 +3874,7 @@ $cfg['Servers'][$i]['AllowDeny']['rules'] = array(
 </a></h4>
 <p>
     Examine the <abbr title="structured query language">SQL</abbr> error with care. Often the problem is caused by
-    specifying a wrong field-type.<br />
+    specifying a wrong column-type.<br />
     Common errors include:
 </p>
 <ul>
@@ -3884,11 +3887,12 @@ $cfg['Servers'][$i]['AllowDeny']['rules'] = array(
 </p>
 
 <h4 id="faq6_2">
-    <a href="#faq6_2">6.2 When I create a table, I set an index for two fields and
-    phpMyAdmin generates only one index with those two fields.
+    <a href="#faq6_2">6.2 When I create a table, I set an index for two
+        columns and
+    phpMyAdmin generates only one index with those two columns.
 </a></h4>
 <p>
-    This is the way to create a multi-fields
+    This is the way to create a multi-columns
     index. If you want two indexes, create the first one when creating the
     table, save, then display the table properties and click the Index link to
     create the other index.
@@ -3897,11 +3901,11 @@ $cfg['Servers'][$i]['AllowDeny']['rules'] = array(
 <h4 id="faq6_3">
     <a href="#faq6_3">6.3 How can I insert a null value into my table?</a></h4>
 <p>
-    Since version 2.2.3, you have a checkbox for each field that can be null.
+    Since version 2.2.3, you have a checkbox for each column that can be null.
     Before 2.2.3, you had to enter "null", without the quotes, as the
-    field's value. Since version 2.5.5, you have to use the checkbox to get
+    column's value. Since version 2.5.5, you have to use the checkbox to get
     a real NULL value, so if you enter "NULL" this means you want
-    a literal NULL in the field, and not a NULL value (this works in PHP4).
+    a literal NULL in the column, and not a NULL value (this works in PHP4).
 </p>
 
 <h4 id="faq6_4">
@@ -3983,7 +3987,7 @@ INSERT INTO REL_towns VALUES ('M', 'Montréal');
     <li>in Links, for "town_code" choose "REL_towns->code"</li>
     <li>in Links, for "country_code" choose "REL_countries->country_code"</li>
     <li>on table "REL_towns" click Structure, then Relation view</li>
-    <li>in "Choose field to display", choose "description"</li>
+    <li>in "Choose column to display", choose "description"</li>
     <li>repeat the two previous steps for table "REL_countries"</li>
 </ul>
 
@@ -3993,7 +3997,7 @@ INSERT INTO REL_towns VALUES ('M', 'Montréal');
     <li>Choose "Query"</li>
     <li>Use tables: persons, towns, countries</li>
     <li>Click "Update query"</li>
-    <li>In the fields row, choose persons.person_name and click the
+    <li>In the columns row, choose persons.person_name and click the
         "Show" tickbox </li>
     <li>Do the same for towns.description and countries.descriptions in the
         other 2 columns</li>
@@ -4003,13 +4007,13 @@ INSERT INTO REL_towns VALUES ('M', 'Montréal');
 </ul>
 
 <h4 id="faqdisplay">
-    <a href="#faqdisplay">6.7 How can I use the "display field" feature?</a></h4>
+    <a href="#faqdisplay">6.7 How can I use the "display column" feature?</a></h4>
 <p>
     Starting from the previous example, create the pma_table_info as explained
     in the configuration section, then browse your persons table,
     and move the mouse over a town code or country code.
     <br /><br />
-    See also <a href="#faq6_21"><abbr title="Frequently Asked Questions">FAQ</abbr> 6.21</a> for an additional feature that "display field"
+    See also <a href="#faq6_21"><abbr title="Frequently Asked Questions">FAQ</abbr> 6.21</a> for an additional feature that "display column"
     enables: drop-down list of possible values.
 </p>
 
@@ -4093,8 +4097,8 @@ INSERT INTO REL_towns VALUES ('M', 'Montréal');
         different structure.</li>
     <li>"Add AUTO_INCREMENT value" ensures that AUTO_INCREMENT value
         (if any) will be included in backup.</li>
-    <li>"Enclose table and field names with backquotes" ensures that
-        field and table names formed with special characters are protected.</li>
+    <li>"Enclose table and column names with backquotes" ensures that
+        column and table names formed with special characters are protected.</li>
     <li>"Add into comments" includes column comments, relations, and MIME
         types set in the pmadb in the dump as
         <abbr title="structured query language">SQL</abbr> comments (<i>/* xxx */</i>).
@@ -4151,15 +4155,15 @@ INSERT INTO REL_towns VALUES ('M', 'Montréal');
     We utilize it as free SOAP service.</p>
 
 <h4 id="faq6_15">
-    <a href="#faq6_15">6.15 I want to add a BLOB field and put an index on
+    <a href="#faq6_15">6.15 I want to add a BLOB column and put an index on
     it, but MySQL says "BLOB column '...' used in key specification without
     a key length".</a></h4>
 
-<p> The right way to do this, is to create the field without any indexes,
+<p> The right way to do this, is to create the column without any indexes,
     then display the table structure and use the "Create an index"
-    dialog. On this page, you will be able to choose your BLOB field, and
+    dialog. On this page, you will be able to choose your BLOB column, and
     set a size to the index, which is the condition to create an index on
-    a BLOB field.</p>
+    a BLOB column.</p>
 
 <h4 id="faq6_16">
     <a href="#faq6_16">6.16 How can I simply move in page with plenty
@@ -4178,7 +4182,7 @@ INSERT INTO REL_towns VALUES ('M', 'Montréal');
     WTF is this feature then useful for?</a></h4>
 
 <p> Slow down :). Defining mimetypes is of no use, if you can't put transformations
-    on them. Otherwise you could just put a comment on the field. Because entering
+    on them. Otherwise you could just put a comment on the column. Because entering
     your own mimetype will cause serious syntax checking issues and validation,
     this introduces a high-risk false-user-input situation. Instead you have to
     initialize mimetypes using functions or empty mimetype definitions.<br />
@@ -4268,17 +4272,17 @@ INSERT INTO REL_towns VALUES ('M', 'Montréal');
 
 <h4 id="faq6_21">
     <a href="#faq6_21">6.21 In edit/insert mode, how can I see a list of
-    possible values for a field, based on some foreign table?</a></h4>
+    possible values for a column, based on some foreign table?</a></h4>
 
 <p> You have to setup appropriate links between the tables, and also
-    setup the "display field" in the foreign table. See
+    setup the "display column" in the foreign table. See
     <a href="#faq6_6"><abbr title="Frequently Asked Questions">FAQ</abbr>
     6.6</a> for an example. Then, if there are 100 values or less in the
     foreign table, a drop-down list of values will be available.
     You will see two lists of values, the first list containing the key
-    and the display field, the second list containing the display field
+    and the display column, the second list containing the display column 
     and the key. The reason for this is to be able to type the first
-    letter of either the key or the display field.<br /><br />
+    letter of either the key or the display column.<br /><br />
 
     For 100 values or more, a distinct window will appear, to browse foreign
     key values and choose one. To change the default limit of 100, see
@@ -4862,7 +4866,7 @@ Jakub Wilk, Thomas Michael Winningham, Vilius Zigmantas, "Manuzhai".
       also contributed the French translation.
   </li>
   <li>Alexandr Bravo <abravo_at_hq.admiral.ru> who contributed
-      tbl_select.php3, a feature to display only some fields from a table.
+      tbl_select.php3, a feature to display only some columns from a table.
   </li>
   <li>Chris Jackson <chrisj_at_ctel.net> added support for MySQL
       functions in tbl_change.php3. He also added the
diff --git a/db_printview.php b/db_printview.php
index e91c04c..a6d66f7 100644
--- a/db_printview.php
+++ b/db_printview.php
@@ -102,7 +102,7 @@ else {
 <thead>
 <tr>
     <th><?php echo __('Table'); ?></th>
-    <th><?php echo __('Records'); ?></th>
+    <th><?php echo __('Rows'); ?></th>
     <th><?php echo __('Type'); ?></th>
     <?php
     if ($cfg['ShowStats']) {
diff --git a/db_qbe.php b/db_qbe.php
index dce1c67..0b661c9 100644
--- a/db_qbe.php
+++ b/db_qbe.php
@@ -171,7 +171,7 @@ function showColumnSelectCell($columns, $column_number, $selected = '')
 <fieldset>
 <table class="data" style="width: 100%;">
 <tr class="odd noclick">
-    <th><?php echo __('Field'); ?>:</th>
+    <th><?php echo __('Column'); ?>:</th>
 <?php
 $z = 0;
 for ($x = 0; $x < $col; $x++) {
@@ -581,7 +581,7 @@ echo PMA_generate_common_hidden_inputs($url_params);
 <table border="0" cellpadding="2" cellspacing="1">
 <tr>
     <td nowrap="nowrap">
-        <?php echo __('Add/Delete Criteria Row'); ?>:
+        <?php echo __('Add/Delete criteria rows'); ?>:
         <select size="1" name="add_row">
             <option value="-3">-3</option>
             <option value="-2">-2</option>
@@ -593,7 +593,7 @@ echo PMA_generate_common_hidden_inputs($url_params);
         </select>
     </td>
     <td width="10"> </td>
-    <td nowrap="nowrap"><?php echo __('Add/Delete Field Columns'); ?>:
+    <td nowrap="nowrap"><?php echo __('Add/Delete columns'); ?>:
         <select size="1" name="add_col">
             <option value="-3">-3</option>
             <option value="-2">-2</option>
diff --git a/db_search.php b/db_search.php
index fece7d0..627ac25 100644
--- a/db_search.php
+++ b/db_search.php
@@ -352,7 +352,7 @@ $alter_select =
             <?php echo $alter_select; ?></td>
     </tr>
     <tr><td align="right">
-            <?php echo __('Inside field:'); ?></td>
+            <?php echo __('Inside column:'); ?></td>
         <td><input type="text" name="field_str" size="60"
                 value="<?php echo ! empty($field_str) ? $field_str : ''; ?>" /></td>
     </tr>
diff --git a/js/messages.php b/js/messages.php
index 30969d6..8eb745a 100644
--- a/js/messages.php
+++ b/js/messages.php
@@ -60,7 +60,7 @@ $js_messages['strGeneralRelationFeat:strDisabled'] = __('General relation featur
 $js_messages['strSelectReferencedKey'] = __('Select referenced key');
 $js_messages['strSelectForeignKey'] = __('Select Foreign Key');
 $js_messages['strPleaseSelectPrimaryOrUniqueKey'] = __('Please select the primary key or a unique key');
-$js_messages['strChangeDisplay'] = __('Choose field to display');
+$js_messages['strChangeDisplay'] = __('Choose column to display');
 
 echo "var PMA_messages = new Array();\n";
 foreach ($js_messages as $name => $js_message) {
diff --git a/libraries/Index.class.php b/libraries/Index.class.php
index 2330642..66a2114 100644
--- a/libraries/Index.class.php
+++ b/libraries/Index.class.php
@@ -443,7 +443,7 @@ class PMA_Index
         $r .= '<th>' . __('Type') . '</th>';
         $r .= '<th>' . __('Unique') . '</th>';
         $r .= '<th>' . __('Packed') . '</th>';
-        $r .= '<th>' . __('Field') . '</th>';
+        $r .= '<th>' . __('Column') . '</th>';
         $r .= '<th>' . __('Cardinality') . '</th>';
         $r .= '<th>' . __('Collation') . '</th>';
         $r .= '<th>' . __('Null') . '</th>';
diff --git a/libraries/db_structure.lib.php b/libraries/db_structure.lib.php
index 7a6dff7..2b6f420 100644
--- a/libraries/db_structure.lib.php
+++ b/libraries/db_structure.lib.php
@@ -19,7 +19,7 @@ if (! defined('PHPMYADMIN')) {
  * @uses    $GLOBALS['is_show_stats']
  * @uses    __('Table')
  * @uses    __('Action')
- * @uses    __('Records')
+ * @uses    __('Rows')
  * @uses    __('May be approximate. See [a at ./Documentation.html#faq3_11 at Documentation]FAQ 3.11[/a]')
  * @uses    __('Type')
  * @uses    __('Collation')
@@ -53,7 +53,7 @@ function PMA_TableHeader($db_is_information_schema = false, $replication = false
         .'        ' . __('Action') . "\n"
         .'    </th>'
         // larger values are more interesting so default sort order is DESC
-        .'    <th>' . PMA_SortableTableHeader(__('Records'), 'records', 'DESC')
+        .'    <th>' . PMA_SortableTableHeader(__('Rows'), 'records', 'DESC')
         .PMA_showHint(PMA_sanitize(__('May be approximate. See [a at ./Documentation.html#faq3_11 at Documentation]FAQ 3.11[/a]'))) . "\n"
         .'    </th>' . "\n";
     if (!($GLOBALS['cfg']['PropertiesNumColumns'] > 1)) {
diff --git a/libraries/display_create_table.lib.php b/libraries/display_create_table.lib.php
index 19512b1..8f1b740 100644
--- a/libraries/display_create_table.lib.php
+++ b/libraries/display_create_table.lib.php
@@ -38,7 +38,7 @@ $is_create_table_priv = true;
 
 ?>
 <form method="post" action="tbl_create.php"
-    onsubmit="return (emptyFormElements(this, 'table') && checkFormElementInRange(this, 'num_fields', '<?php echo str_replace('\'', '\\\'', __('Table must have at least one field.')); ?>', 1))">
+    onsubmit="return (emptyFormElements(this, 'table') && checkFormElementInRange(this, 'num_fields', '<?php echo str_replace('\'', '\\\'', __('Table must have at least one column.')); ?>', 1))">
 <fieldset>
     <legend>
 <?php
@@ -54,7 +54,7 @@ echo sprintf(__('Create table on database %s'), PMA_getDbLink());
         <input type="text" name="table" maxlength="64" size="30" />
     </div>
     <div class="formelement">
-        <?php echo __('Number of fields'); ?>:
+        <?php echo __('Number of columns'); ?>:
         <input type="text" name="num_fields" size="2" />
     </div>
     <div class="clearfloat"></div>
diff --git a/libraries/display_export.lib.php b/libraries/display_export.lib.php
index ec7affc..54867f5 100644
--- a/libraries/display_export.lib.php
+++ b/libraries/display_export.lib.php
@@ -104,7 +104,7 @@ echo PMA_pluginGetJavascript($export_list);
         <?php
         echo '<input type="radio" name="allrows" value="0" id="radio_allrows_0" checked="checked" />';
 
-        echo sprintf(__('Dump %s row(s) starting at record # %s'),
+        echo sprintf(__('Dump %s row(s) starting at row # %s'),
             '<input type="text" name="limit_to" size="5" value="'
             . (isset($unlim_num_rows) ? $unlim_num_rows : PMA_Table::countRecords($db, $table))
             . '" onfocus="this.select()" />',
diff --git a/libraries/display_import.lib.php b/libraries/display_import.lib.php
index d30619d..923d962 100644
--- a/libraries/display_import.lib.php
+++ b/libraries/display_import.lib.php
@@ -236,7 +236,7 @@ if ($_SESSION[$SESSION_KEY]["handler"]!="noplugin") {
         if (! (isset($timeout_passed) && $timeout_passed)) {
             ?>
         <div class="formelementrow">
-            <label for="text_skip_queries"><?php echo __('Number of records (queries) to skip from start'); ?></label>
+            <label for="text_skip_queries"><?php echo __('Number of queries to skip from start'); ?></label>
             <input type="text" name="skip_queries" value="<?php echo PMA_pluginGetDefault('Import', 'skip_queries');?>" id="text_skip_queries" />
         </div>
             <?php
diff --git a/libraries/display_tbl.lib.php b/libraries/display_tbl.lib.php
index 538409f..5238d93 100644
--- a/libraries/display_tbl.lib.php
+++ b/libraries/display_tbl.lib.php
@@ -307,7 +307,7 @@ onsubmit="return (checkFormElementInRange(this, 'session_max_rows', '<?php echo
         <input type="hidden" name="goto" value="<?php echo $goto; ?>" />
         <input type="submit" name="navig" value="<?php echo __('Show'); ?> :" />
         <input type="text" name="session_max_rows" size="3" value="<?php echo (($_SESSION['tmp_user_values']['max_rows'] != 'all') ? $_SESSION['tmp_user_values']['max_rows'] : $GLOBALS['cfg']['MaxRows']); ?>" class="textfield" onfocus="this.select()" />
-        <?php echo __('row(s) starting from record #') . "\n"; ?>
+        <?php echo __('row(s) starting from row #') . "\n"; ?>
         <input type="text" name="pos" size="6" value="<?php echo (($pos_next >= $unlim_num_rows) ? 0 : $pos_next); ?>" class="textfield" onfocus="this.select()" />
         <br />
     <?php
@@ -585,7 +585,7 @@ function PMA_displayTableHeaders(&$is_display, &$fields_meta, $fields_cnt = 0, $
             echo '<div class="formelement">';
             $choices = array(
                 'K'   => __('Relational key'),
-                'D'   => __('Relational display field')
+                'D'   => __('Relational display column')
             );
             PMA_display_html_radio('relational_display', $choices, $_SESSION['tmp_user_values']['relational_display']);
             echo '</div>';
diff --git a/libraries/export/csv.php b/libraries/export/csv.php
index 5bc490d..e3d78f2 100644
--- a/libraries/export/csv.php
+++ b/libraries/export/csv.php
@@ -18,13 +18,13 @@ if (isset($plugin_list)) {
         'extension' => 'csv',
         'mime_type' => 'text/comma-separated-values',
         'options' => array(
-            array('type' => 'text', 'name' => 'separator', 'text' => __('Fields terminated by')),
-            array('type' => 'text', 'name' => 'enclosed', 'text' => __('Fields enclosed by')),
-            array('type' => 'text', 'name' => 'escaped', 'text' => __('Fields escaped by')),
+            array('type' => 'text', 'name' => 'separator', 'text' => __('Columns terminated by')),
+            array('type' => 'text', 'name' => 'enclosed', 'text' => __('Columns enclosed by')),
+            array('type' => 'text', 'name' => 'escaped', 'text' => __('Columns escaped by')),
             array('type' => 'text', 'name' => 'terminated', 'text' => __('Lines terminated by')),
             array('type' => 'text', 'name' => 'null', 'text' => __('Replace NULL by')),
-            array('type' => 'bool', 'name' => 'removeCRLF', 'text' => __('Remove CRLF characters within fields')),
-            array('type' => 'bool', 'name' => 'columns', 'text' => __('Put fields names in the first row')),
+            array('type' => 'bool', 'name' => 'removeCRLF', 'text' => __('Remove CRLF characters within columns')),
+            array('type' => 'bool', 'name' => 'columns', 'text' => __('Put columns names in the first row')),
             array('type' => 'hidden', 'name' => 'data'),
             ),
         'options_text' => __('Options'),
diff --git a/libraries/export/excel.php b/libraries/export/excel.php
index 92d0bce..768fa3d 100644
--- a/libraries/export/excel.php
+++ b/libraries/export/excel.php
@@ -20,8 +20,8 @@ if (isset($plugin_list)) {
         'mime_type' => 'text/comma-separated-values',
         'options' => array(
             array('type' => 'text', 'name' => 'null', 'text' => __('Replace NULL by')),
-            array('type' => 'bool', 'name' => 'removeCRLF', 'text' => __('Remove CRLF characters within fields')),
-            array('type' => 'bool', 'name' => 'columns', 'text' => __('Put fields names in the first row')),
+            array('type' => 'bool', 'name' => 'removeCRLF', 'text' => __('Remove CRLF characters within columns')),
+            array('type' => 'bool', 'name' => 'columns', 'text' => __('Put columns names in the first row')),
             array(
                 'type' => 'select', 
                 'name' => 'edition', 
diff --git a/libraries/export/htmlword.php b/libraries/export/htmlword.php
index 2f4441a..5f36dc9 100644
--- a/libraries/export/htmlword.php
+++ b/libraries/export/htmlword.php
@@ -23,7 +23,7 @@ if (isset($plugin_list)) {
             array('type' => 'bool', 'name' => 'structure', 'text' => __('Structure'), 'force' => 'data'),
             array('type' => 'bgroup', 'name' => 'data', 'text' => __('Data'), 'force' => 'structure'),
             array('type' => 'text', 'name' => 'null', 'text' => __('Replace NULL by')),
-            array('type' => 'bool', 'name' => 'columns', 'text' => __('Put fields names in the first row')),
+            array('type' => 'bool', 'name' => 'columns', 'text' => __('Put columns names in the first row')),
             array('type' => 'egroup'),
             ),
         'options_text' => __('Options'),
@@ -241,7 +241,7 @@ function PMA_exportStructure($db, $table, $crlf, $error_url, $do_relation = fals
     }
 
     $schema_insert = '<tr class="print-category">';
-    $schema_insert .= '<th class="print">' . htmlspecialchars(__('Field')) . '</th>';
+    $schema_insert .= '<th class="print">' . htmlspecialchars(__('Column')) . '</th>';
     $schema_insert .= '<td class="print"><b>' . htmlspecialchars(__('Type')) . '</b></td>';
     $schema_insert .= '<td class="print"><b>' . htmlspecialchars(__('Null')) . '</b></td>';
     $schema_insert .= '<td class="print"><b>' . htmlspecialchars(__('Default')) . '</b></td>';
diff --git a/libraries/export/latex.php b/libraries/export/latex.php
index 232d378..cba335a 100644
--- a/libraries/export/latex.php
+++ b/libraries/export/latex.php
@@ -54,7 +54,7 @@ if (isset($plugin_list)) {
     $plugin_list['latex']['options'][] =
         array('type' => 'bgroup', 'name' => 'data', 'text' => __('Data'), 'force' => 'structure');
     $plugin_list['latex']['options'][] =
-        array('type' => 'bool', 'name' => 'columns', 'text' => __('Put fields names in the first row'));
+        array('type' => 'bool', 'name' => 'columns', 'text' => __('Put columns names in the first row'));
     $plugin_list['latex']['options'][] =
         array('type' => 'text', 'name' => 'data_caption', 'text' => __('Table caption'));
     $plugin_list['latex']['options'][] =
@@ -357,7 +357,7 @@ function PMA_exportStructure($db, $table, $crlf, $error_url, $do_relation = fals
     $buffer = $alignment . '} ' . $crlf ;
 
     $header = ' \\hline ';
-    $header .= '\\multicolumn{1}{|c|}{\\textbf{' . __('Field') . '}} & \\multicolumn{1}{|c|}{\\textbf{' . __('Type') . '}} & \\multicolumn{1}{|c|}{\\textbf{' . __('Null') . '}} & \\multicolumn{1}{|c|}{\\textbf{' . __('Default') . '}}';
+    $header .= '\\multicolumn{1}{|c|}{\\textbf{' . __('Column') . '}} & \\multicolumn{1}{|c|}{\\textbf{' . __('Type') . '}} & \\multicolumn{1}{|c|}{\\textbf{' . __('Null') . '}} & \\multicolumn{1}{|c|}{\\textbf{' . __('Default') . '}}';
     if ($do_relation && $have_rel) {
         $header .= ' & \\multicolumn{1}{|c|}{\\textbf{' . __('Links to') . '}}';
     }
diff --git a/libraries/export/ods.php b/libraries/export/ods.php
index c8dee56..78fd6f2 100644
--- a/libraries/export/ods.php
+++ b/libraries/export/ods.php
@@ -21,7 +21,7 @@ if (isset($plugin_list)) {
         'force_file' => true,
         'options' => array(
             array('type' => 'text', 'name' => 'null', 'text' => __('Replace NULL by')),
-            array('type' => 'bool', 'name' => 'columns', 'text' => __('Put fields names in the first row')),
+            array('type' => 'bool', 'name' => 'columns', 'text' => __('Put columns names in the first row')),
             array('type' => 'hidden', 'name' => 'data'),
             ),
         'options_text' => __('Options'),
diff --git a/libraries/export/odt.php b/libraries/export/odt.php
index 9b3239b..157fc43 100644
--- a/libraries/export/odt.php
+++ b/libraries/export/odt.php
@@ -47,7 +47,7 @@ if (isset($plugin_list)) {
     $plugin_list['odt']['options'][] =
         array('type' => 'bgroup', 'name' => 'data', 'text' => __('Data'), 'force' => 'structure');
     $plugin_list['odt']['options'][] =
-        array('type' => 'bool', 'name' => 'columns', 'text' => __('Put fields names in the first row'));
+        array('type' => 'bool', 'name' => 'columns', 'text' => __('Put columns names in the first row'));
     $plugin_list['odt']['options'][] =
         array('type' => 'text', 'name' => 'null', 'text' => __('Replace NULL by'));
     $plugin_list['odt']['options'][] =
@@ -291,7 +291,7 @@ function PMA_exportStructure($db, $table, $crlf, $error_url, $do_relation = fals
     /* Header */
     $GLOBALS['odt_buffer'] .= '<table:table-row>';
     $GLOBALS['odt_buffer'] .= '<table:table-cell office:value-type="string">'
-        . '<text:p>' . htmlspecialchars(__('Field')) . '</text:p>'
+        . '<text:p>' . htmlspecialchars(__('Column')) . '</text:p>'
         . '</table:table-cell>';
     $GLOBALS['odt_buffer'] .= '<table:table-cell office:value-type="string">'
         . '<text:p>' . htmlspecialchars(__('Type')) . '</text:p>'
diff --git a/libraries/export/sql.php b/libraries/export/sql.php
index 31f35c4..4c42a91 100644
--- a/libraries/export/sql.php
+++ b/libraries/export/sql.php
@@ -77,7 +77,7 @@ if (isset($plugin_list)) {
             $plugin_list['sql']['options'][] =
                 array('type' => 'bool', 'name' => 'auto_increment', 'text' => __('Add AUTO_INCREMENT value'));
             $plugin_list['sql']['options'][] =
-                array('type' => 'bool', 'name' => 'backquotes', 'text' => __('Enclose table and field names with backquotes'));
+                array('type' => 'bool', 'name' => 'backquotes', 'text' => __('Enclose table and column names with backquotes'));
             $plugin_list['sql']['options'][] =
                 array('type' => 'bool', 'name' => 'procedure_function', 'text' => sprintf(__('Add %s'), 'CREATE PROCEDURE / FUNCTION' . (PMA_MYSQL_INT_VERSION > 50100 ? ' / EVENT' : '')));
 
diff --git a/libraries/export/texytext.php b/libraries/export/texytext.php
index 4eeba65..eeb1615 100644
--- a/libraries/export/texytext.php
+++ b/libraries/export/texytext.php
@@ -31,7 +31,7 @@ if (isset($plugin_list)) {
                 'text' => __('Replace NULL by')),
             array('type' => 'bool',
                 'name' => 'columns',
-                'text' => __('Put fields names in the first row')),
+                'text' => __('Put columns names in the first row')),
             array('type' => 'egroup'),
             ),
         'options_text' => __('Options'),
@@ -230,7 +230,7 @@ function PMA_exportStructure($db, $table, $crlf, $error_url, $do_relation = fals
     }
 
     $text_output = "|------\n";
-    $text_output .= '|' . htmlspecialchars(__('Field'));
+    $text_output .= '|' . htmlspecialchars(__('Column'));
     $text_output .= '|' . htmlspecialchars(__('Type'));
     $text_output .= '|' . htmlspecialchars(__('Null'));
     $text_output .= '|' . htmlspecialchars(__('Default'));
diff --git a/libraries/export/xls.php b/libraries/export/xls.php
index ed13c15..d238903 100644
--- a/libraries/export/xls.php
+++ b/libraries/export/xls.php
@@ -21,7 +21,7 @@ if (isset($plugin_list)) {
         'force_file' => true,
         'options' => array(
             array('type' => 'text', 'name' => 'null', 'text' => __('Replace NULL by')),
-            array('type' => 'bool', 'name' => 'columns', 'text' => __('Put fields names in the first row')),
+            array('type' => 'bool', 'name' => 'columns', 'text' => __('Put columns names in the first row')),
             array('type' => 'hidden', 'name' => 'data'),
             ),
         'options_text' => __('Options'),
diff --git a/libraries/export/xlsx.php b/libraries/export/xlsx.php
index fb323bf..b59c78c 100644
--- a/libraries/export/xlsx.php
+++ b/libraries/export/xlsx.php
@@ -21,7 +21,7 @@ if (isset($plugin_list)) {
         'force_file' => true,
         'options' => array(
             array('type' => 'text', 'name' => 'null', 'text' => __('Replace NULL by')),
-            array('type' => 'bool', 'name' => 'columns', 'text' => __('Put fields names in the first row')),
+            array('type' => 'bool', 'name' => 'columns', 'text' => __('Put columns names in the first row')),
             array('type' => 'hidden', 'name' => 'data'),
             ),
         'options_text' => __('Options'),
diff --git a/libraries/import/csv.php b/libraries/import/csv.php
index d10d6df..170fb96 100644
--- a/libraries/import/csv.php
+++ b/libraries/import/csv.php
@@ -24,9 +24,9 @@ if (isset($plugin_list)) {
         'options' => array(
             array('type' => 'bool', 'name' => 'replace', 'text' => __('Replace table data with file')),
             array('type' => 'bool', 'name' => 'ignore', 'text' => __('Ignore duplicate rows')),
-            array('type' => 'text', 'name' => 'terminated', 'text' => __('Fields terminated by'), 'size' => 2, 'len' => 2),
-            array('type' => 'text', 'name' => 'enclosed', 'text' => __('Fields enclosed by'), 'size' => 2, 'len' => 2),
-            array('type' => 'text', 'name' => 'escaped', 'text' => __('Fields escaped by'), 'size' => 2, 'len' => 2),
+            array('type' => 'text', 'name' => 'terminated', 'text' => __('Columns terminated by'), 'size' => 2, 'len' => 2),
+            array('type' => 'text', 'name' => 'enclosed', 'text' => __('Columns enclosed by'), 'size' => 2, 'len' => 2),
+            array('type' => 'text', 'name' => 'escaped', 'text' => __('Columns escaped by'), 'size' => 2, 'len' => 2),
             array('type' => 'text', 'name' => 'new_line', 'text' => __('Lines terminated by'), 'size' => 2),
             ),
         'options_text' => __('Options'),
@@ -56,7 +56,7 @@ $csv_new_line = strtr($csv_new_line, $replacements);
 
 if (strlen($csv_terminated) != 1) {
     $message = PMA_Message::error(__('Invalid parameter for CSV import: %s'));
-    $message->addParam(__('Fields terminated by'), false);
+    $message->addParam(__('Columns terminated by'), false);
     $error = TRUE;
     // The default dialog of MS Excel when generating a CSV produces a
     // semi-colon-separated file with no chance of specifying the
@@ -68,11 +68,11 @@ if (strlen($csv_terminated) != 1) {
     // one character.
 } elseif (strlen($csv_enclosed) > 1) {
     $message = PMA_Message::error(__('Invalid parameter for CSV import: %s'));
-    $message->addParam(__('Fields enclosed by'), false);
+    $message->addParam(__('Columns enclosed by'), false);
     $error = TRUE;
 } elseif (strlen($csv_escaped) != 1) {
     $message = PMA_Message::error(__('Invalid parameter for CSV import: %s'));
-    $message->addParam(__('Fields escaped by'), false);
+    $message->addParam(__('Columns escaped by'), false);
     $error = TRUE;
 } elseif (strlen($csv_new_line) != 1 && $csv_new_line != 'auto') {
     $message = PMA_Message::error(__('Invalid parameter for CSV import: %s'));
@@ -309,7 +309,7 @@ while (!($finished && $i >= $len) && !$error && !$timeout_passed) {
                     if ($values[count($values) - 1] == ';') {
                         unset($values[count($values) - 1]);
                     } else {
-                        $message = PMA_Message::error(__('Invalid field count in CSV input on line %d.'));
+                        $message = PMA_Message::error(__('Invalid column count in CSV input on line %d.'));
                         $message->addParam($line);
                         $error = TRUE;
                         break;
diff --git a/libraries/import/ldi.php b/libraries/import/ldi.php
index 47516aa..2c8702a 100644
--- a/libraries/import/ldi.php
+++ b/libraries/import/ldi.php
@@ -37,9 +37,9 @@ if (isset($plugin_list)) {
         'options' => array(
             array('type' => 'bool', 'name' => 'replace', 'text' => __('Replace table data with file')),
             array('type' => 'bool', 'name' => 'ignore', 'text' => __('Ignore duplicate rows')),
-            array('type' => 'text', 'name' => 'terminated', 'text' => __('Fields terminated by'), 'size' => 2, 'len' => 2),
-            array('type' => 'text', 'name' => 'enclosed', 'text' => __('Fields enclosed by'), 'size' => 2, 'len' => 2),
-            array('type' => 'text', 'name' => 'escaped', 'text' => __('Fields escaped by'), 'size' => 2, 'len' => 2),
+            array('type' => 'text', 'name' => 'terminated', 'text' => __('Columns terminated by'), 'size' => 2, 'len' => 2),
+            array('type' => 'text', 'name' => 'enclosed', 'text' => __('Columns enclosed by'), 'size' => 2, 'len' => 2),
+            array('type' => 'text', 'name' => 'escaped', 'text' => __('Columns escaped by'), 'size' => 2, 'len' => 2),
             array('type' => 'text', 'name' => 'new_line', 'text' => __('Lines terminated by'), 'size' => 2),
             array('type' => 'text', 'name' => 'columns', 'text' => __('Column names')),
             array('type' => 'bool', 'name' => 'local_option', 'text' => __('Use LOCAL keyword')),
diff --git a/libraries/sql_query_form.lib.php b/libraries/sql_query_form.lib.php
index eeee671..6a4b6e9 100644
--- a/libraries/sql_query_form.lib.php
+++ b/libraries/sql_query_form.lib.php
@@ -314,7 +314,7 @@ function PMA_sqlQueryFormInsert($query = '', $is_querywindow = false, $delimiter
 
     if (count($fields_list)) {
         echo '<div id="tablefieldscontainer">' . "\n"
-            .'<label>' . __('Fields') . '</label>' . "\n"
+            .'<label>' . __('Columns') . '</label>' . "\n"
             .'<select id="tablefields" name="dummy" '
             .'size="' . ($GLOBALS['cfg']['TextareaRows'] - 2) . '" '
             .'multiple="multiple" ondblclick="insertValueQuery()">' . "\n";
diff --git a/libraries/tbl_properties.inc.php b/libraries/tbl_properties.inc.php
index 7cce097..0d00d17 100644
--- a/libraries/tbl_properties.inc.php
+++ b/libraries/tbl_properties.inc.php
@@ -96,13 +96,13 @@ $is_backup = ($action != 'tbl_create.php' && $action != 'tbl_addfield.php');
 $header_cells = array();
 $content_cells = array();
 
-$header_cells[] = __('Field');
+$header_cells[] = __('Column');
 $header_cells[] = __('Type')
      . ($GLOBALS['cfg']['ReplaceHelpImg']
         ? PMA_showMySQLDocu('SQL-Syntax', 'data-types')
         : '<br /><span style="font-weight: normal">' . PMA_showMySQLDocu('SQL-Syntax', 'data-types')
      . '</span>');
-$header_cells[] = __('Length/Values') . PMA_showHint(__('If field type is "enum" or "set", please enter the values using this format: \'a\',\'b\',\'c\'...<br />If you ever need to put a backslash ("\") or a single quote ("\'") amongst those values, precede it with a backslash (for example \'\\\\xyz\' or \'a\\\'b\').'));
+$header_cells[] = __('Length/Values') . PMA_showHint(__('If column type is "enum" or "set", please enter the values using this format: \'a\',\'b\',\'c\'...<br />If you ever need to put a backslash ("\") or a single quote ("\'") amongst those values, precede it with a backslash (for example \'\\\\xyz\' or \'a\\\'b\').'));
 $header_cells[] = __('Default') . PMA_showHint(__('For default values, please enter just a single value, without backslash escaping or quotes, using this format: a'));
 $header_cells[] = __('Collation');
 $header_cells[] = __('Attributes');
@@ -272,7 +272,7 @@ for ($i = 0; $i < $num_fields; $i++) {
     // column name
     $content_cells[$i][$ci] = '<input id="field_' . $i . '_' . ($ci - $ci_offset) . '"'
         . ' type="text" name="field_name[' . $i . ']"'
-        . ' maxlength="64" class="textfield" title="' . __('Field') . '"'
+        . ' maxlength="64" class="textfield" title="' . __('Column') . '"'
         . ' size="' . ($GLOBALS['cfg']['DefaultPropDisplay'] == 'horizontal' ? '10' : '30') . '"'
         . ' value="' . (isset($row['Field']) ? htmlspecialchars($row['Field']) : '') . '"'
         . ' />';
@@ -777,11 +777,11 @@ if ($action == 'tbl_create.php') {
         onclick="return checkTableEditForm(this.form, <?php echo $num_fields; ?>)" />
 <?php if ($action == 'tbl_create.php' || $action == 'tbl_addfield.php') { ?>
     <?php echo __('Or'); ?>
-    <?php echo sprintf(__('Add %s field(s)'), '<input type="text" id="added_fields" name="added_fields" size="2" value="1" onfocus="this.select()" />'); ?>
+    <?php echo sprintf(__('Add %s column(s)'), '<input type="text" id="added_fields" name="added_fields" size="2" value="1" onfocus="this.select()" />'); ?>
     <input type="submit" name="submit_num_fields"
         value="<?php echo __('Go'); ?>"
 <?php /*        onclick="if (addField()) return false;" */ ?>
-        onclick="return checkFormElementInRange(this.form, 'added_fields', '<?php echo str_replace('\'', '\\\'', __('You have to add at least one field.')); ?>', 1)"
+        onclick="return checkFormElementInRange(this.form, 'added_fields', '<?php echo str_replace('\'', '\\\'', __('You have to add at least one column.')); ?>', 1)"
         />
 <?php } ?>
 </fieldset>
diff --git a/libraries/transformations/application_octetstream__download.inc.php b/libraries/transformations/application_octetstream__download.inc.php
index 369126d..4fbc24d 100644
--- a/libraries/transformations/application_octetstream__download.inc.php
+++ b/libraries/transformations/application_octetstream__download.inc.php
@@ -7,7 +7,7 @@
 
 function PMA_transformation_application_octetstream__download_info() {
     return array(
-        'info' =>  __('Displays a link to download the binary data of the field. You can use the first option to specify the filename, or use the second option as the name of a field which contains the filename. If you use the second option, you need to set the first option to the empty string.'),
+        'info' =>  __('Displays a link to download the binary data of the column. You can use the first option to specify the filename, or use the second option as the name of a column which contains the filename. If you use the second option, you need to set the first option to the empty string.'),
         );
 }
 
diff --git a/libraries/transformations/text_plain__dateformat.inc.php b/libraries/transformations/text_plain__dateformat.inc.php
index 3f11fa9..cf3c2b0 100644
--- a/libraries/transformations/text_plain__dateformat.inc.php
+++ b/libraries/transformations/text_plain__dateformat.inc.php
@@ -7,7 +7,7 @@
 
 function PMA_transformation_text_plain__dateformat_info() {
     return array(
-        'info' => __('Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.'),
+        'info' => __('Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp column as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.'),
         );
 }
 
diff --git a/libraries/transformations/text_plain__external.inc.php b/libraries/transformations/text_plain__external.inc.php
index 981faec..8c35a4e 100644
--- a/libraries/transformations/text_plain__external.inc.php
+++ b/libraries/transformations/text_plain__external.inc.php
@@ -7,7 +7,7 @@
 
 function PMA_transformation_text_plain__external_info() {
     return array(
-        'info' => __('LINUX ONLY: Launches an external application and feeds it the field data via standard input. Returns the standard output of the application. The default is Tidy, to pretty-print HTML code. For security reasons, you have to manually edit the file libraries/transformations/text_plain__external.inc.php and list the tools you want to make available. The first option is then the number of the program you want to use and the second option is the parameters for the program. The third option, if set to 1, will convert the output using htmlspecialchars() (Default 1). The fourth option, if set to 1, will prevent wrapping and ensure that the output appears all on one line (Default 1).'),
+        'info' => __('LINUX ONLY: Launches an external application and feeds it the column data via standard input. Returns the standard output of the application. The default is Tidy, to pretty-print HTML code. For security reasons, you have to manually edit the file libraries/transformations/text_plain__external.inc.php and list the tools you want to make available. The first option is then the number of the program you want to use and the second option is the parameters for the program. The third option, if set to 1, will convert the output using htmlspecialchars() (Default 1). The fourth option, if set to 1, will prevent wrapping and ensure that the output appears all on one line (Default 1).'),
         );
 }
 
diff --git a/libraries/transformations/text_plain__formatted.inc.php b/libraries/transformations/text_plain__formatted.inc.php
index 7a1e8f8..add22e1 100644
--- a/libraries/transformations/text_plain__formatted.inc.php
+++ b/libraries/transformations/text_plain__formatted.inc.php
@@ -7,7 +7,7 @@
 
 function PMA_transformation_text_plain__formatted_info() {
     return array(
-        'info' => __('Displays the contents of the field as-is, without running it through htmlspecialchars(). That is, the field is assumed to contain valid HTML.'),
+        'info' => __('Displays the contents of the column as-is, without running it through htmlspecialchars(). That is, the column is assumed to contain valid HTML.'),
         );
 }
 
diff --git a/libraries/transformations/text_plain__imagelink.inc.php b/libraries/transformations/text_plain__imagelink.inc.php
index d743a16..cb62067 100644
--- a/libraries/transformations/text_plain__imagelink.inc.php
+++ b/libraries/transformations/text_plain__imagelink.inc.php
@@ -7,7 +7,7 @@
 
 function PMA_transformation_text_plain__imagelink_info() {
     return array(
-        'info' => __('Displays an image and a link; the field contains the filename. The first option is a URL prefix like "http://www.example.com/". The second and third options are the width and the height in pixels.'),
+        'info' => __('Displays an image and a link; the column contains the filename. The first option is a URL prefix like "http://www.example.com/". The second and third options are the width and the height in pixels.'),
         );
 }
 
diff --git a/libraries/transformations/text_plain__link.inc.php b/libraries/transformations/text_plain__link.inc.php
index f9e2bf1..579deda 100644
--- a/libraries/transformations/text_plain__link.inc.php
+++ b/libraries/transformations/text_plain__link.inc.php
@@ -7,7 +7,7 @@
 
 function PMA_transformation_text_plain__link_info() {
     return array(
-        'info' => __('Displays a link; the field contains the filename. The first option is a URL prefix like "http://www.example.com/". The second option is a title for the link.'),
+        'info' => __('Displays a link; the column contains the filename. The first option is a URL prefix like "http://www.example.com/". The second option is a title for the link.'),
         );
 }
 
diff --git a/pdf_schema.php b/pdf_schema.php
index 3156d21..598c9a4 100644
--- a/pdf_schema.php
+++ b/pdf_schema.php
@@ -1259,7 +1259,7 @@ function PMA_RT_DOC($alltables)
 
         $pdf->SetFont('', 'B');
         if (isset($orientation) && $orientation == 'L') {
-            $pdf->Cell(25, 8, ucfirst(__('Field')), 1, 0, 'C');
+            $pdf->Cell(25, 8, ucfirst(__('Column')), 1, 0, 'C');
             $pdf->Cell(20, 8, ucfirst(__('Type')), 1, 0, 'C');
             $pdf->Cell(20, 8, ucfirst(__('Attributes')), 1, 0, 'C');
             $pdf->Cell(10, 8, ucfirst(__('Null')), 1, 0, 'C');
@@ -1280,7 +1280,7 @@ function PMA_RT_DOC($alltables)
             $pdf->Cell(45, 8, 'MIME', 1, 1, 'C');
             $pdf->SetWidths(array(25, 20, 20, 10, 20, 25, 45, $comments_width, 45));
         } else {
-            $pdf->Cell(20, 8, ucfirst(__('Field')), 1, 0, 'C');
+            $pdf->Cell(20, 8, ucfirst(__('Column')), 1, 0, 'C');
             $pdf->Cell(20, 8, ucfirst(__('Type')), 1, 0, 'C');
             $pdf->Cell(20, 8, ucfirst(__('Attributes')), 1, 0, 'C');
             $pdf->Cell(10, 8, ucfirst(__('Null')), 1, 0, 'C');
diff --git a/pmd_general.php b/pmd_general.p
hp
index 5a4e9d9..89988dd 100644
--- a/pmd_general.php
+++ b/pmd_general.php
@@ -74,7 +74,7 @@ echo $script_tabs . $script_contr . $script_display_field;
         ><img title="<?php echo __('Create relation') ?>" src="pmd/images/relation.png" alt=""
         /></a><a href="javascript:Start_display_field();" onmousedown="return false;"
             class="M_butt" id="display_field_button" target="_self"
-        ><img title="<?php echo __('Choose field to display') ?>" src="pmd/images/display_field.png" alt=""
+        ><img title="<?php echo __('Choose column to display') ?>" src="pmd/images/display_field.png" alt=""
         /></a><a href="javascript:location.reload();" onmousedown="return false;"
             class="M_butt" target="_self"
         ><img title="<?php echo __('Reload'); ?>" src="pmd/images/reload.png" alt=""
diff --git a/pmd_help.php b/pmd_help.php
index 328645b..e538a48 100644
--- a/pmd_help.php
+++ b/pmd_help.php
@@ -26,7 +26,7 @@ require_once 'pmd_common.php';
 <?php
     echo '<p>' . __('To select relation, click :') . '<br />';
     echo '<img src="pmd/images/help_relation.png" border="1"></p>';
-    echo '<p>' . __('The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.') . '</p>';
+    echo '<p>' . __('The display column is shown in pink. To set/unset a column as the display column, click the "Choose column to display" icon, then click on the appropriate column name.') . '</p>';
 ?>
 </body>
 </html>
diff --git a/setup/lib/messages.inc.php b/setup/lib/messages.inc.php
index b9ec8b3..1defa2d 100644
--- a/setup/lib/messages.inc.php
+++ b/setup/lib/messages.inc.php
@@ -32,8 +32,8 @@ $strSetupBZipDump_name = __('Bzip2');
 $strSetupBZipDumpWarning = __('[a@?page=form&formset=features#tab_Import_export]Bzip2 compression and decompression[/a] requires functions (%s) which are unavailable on this system.');
 $strSetupCannotLoadConfig = __('Cannot load or save configuration');
 $strSetupCannotLoadConfigMsg = __('Please create web server writable folder [em]config[/em] in phpMyAdmin top level directory as described in [a at ../Documentation.html#setup_script]documentation[/a]. Otherwise you will be only able to download or display it.');
-$strSetupCharEditing_desc = __('Defines which type of editing controls should be used for CHAR and VARCHAR fields; [kbd]input[/kbd] - allows limiting of input length, [kbd]textarea[/kbd] - allows newlines in fields');
-$strSetupCharEditing_name = __('CHAR fields editing');
+$strSetupCharEditing_desc = __('Defines which type of editing controls should be used for CHAR and VARCHAR columns; [kbd]input[/kbd] - allows limiting of input length, [kbd]textarea[/kbd] - allows newlines in columns');
+$strSetupCharEditing_name = __('CHAR columns editing');
 $strSetupCharTextareaCols_desc = __('Number of columns for CHAR/VARCHAR textareas');
 $strSetupCharTextareaCols_name = __('CHAR textarea columns');
 $strSetupCharTextareaRows_desc = __('Number of rows for CHAR/VARCHAR textareas');
@@ -158,7 +158,7 @@ $strSetupImport_allow_interrupt_desc = __('Allow interrupt of import in case scr
 $strSetupImport_allow_interrupt_name = __('Partial import: allow interrupt');
 $strSetupImport_format_desc = __('Default format; be aware that this list depends on location (database, table) and only SQL is always available');
 $strSetupImport_format_name = __('Format of imported file');
-$strSetupImport_skip_queries_desc = __('Number of records (queries) to skip from start');
+$strSetupImport_skip_queries_desc = __('Number of queries to skip from start');
 $strSetupImport_skip_queries_name = __('Partial import: skip queries');
 $strSetupInsecureConnection = __('Insecure connection');
 $strSetupInsecureConnectionMsg1 = __('You are not using a secure connection; all data (including potentially sensitive information, like passwords) is transferred unencrypted!');
@@ -214,15 +214,15 @@ $strSetupNoServers = __('There are no configured servers');
 $strSetupOBGzip_desc = __('use GZip output buffering for increased speed in HTTP transfers');
 $strSetupOBGzip_name = __('GZip output buffering');
 $strSetupOptionNone = __('- none -');
-$strSetupOrder_desc = __('[kbd]SMART[/kbd] - i.e. descending order for fields of type TIME, DATE, DATETIME and TIMESTAMP, ascending order otherwise');
+$strSetupOrder_desc = __('[kbd]SMART[/kbd] - i.e. descending order for columns of type TIME, DATE, DATETIME and TIMESTAMP, ascending order otherwise');
 $strSetupOrder_name = __('Default sorting order');
 $strSetupOverview = __('Overview');
 $strSetupPersistentConnections_desc = __('Use persistent connections to MySQL databases');
 $strSetupPersistentConnections_name = __('Persistent connections');
 $strSetupPropertiesIconic_desc = __('Use only icons, only text or both');
 $strSetupPropertiesIconic_name = __('Iconic table operations');
-$strSetupProtectBinary_desc = __('Disallow BLOB and BINARY fields from editing');
-$strSetupProtectBinary_name = __('Protect binary fields');
+$strSetupProtectBinary_desc = __('Disallow BLOB and BINARY columns from editing');
+$strSetupProtectBinary_name = __('Protect binary columns');
 $strSetupQueryHistoryDB_desc = __('Enable if you want DB-based query history (requires pmadb). If disabled, this utilizes JS-routines to display query history (lost by window close).');
 $strSetupQueryHistoryDB_name = __('Permanent query history');
 $strSetupQueryHistoryMax_desc = __('How many queries are kept in history');
@@ -317,8 +317,8 @@ $strSetupServers_ssl_desc = __('Enable SSL for connection to MySQL server');
 $strSetupServers_ssl_name = __('Use SSL');
 $strSetupServers_table_coords_desc = __('Leave blank for no PDF schema support, suggested: [kbd]pma_table_coords[/kbd]');
 $strSetupServers_table_coords_name = __('PDF schema: table coordinates');
-$strSetupServers_table_info_desc = __('Table to describe the display fields, leave blank for no support; suggested: [kbd]pma_table_info[/kbd]');
-$strSetupServers_table_info_name = __('Display fields table');
+$strSetupServers_table_info_desc = __('Table to describe the display columns, leave blank for no support; suggested: [kbd]pma_table_info[/kbd]');
+$strSetupServers_table_info_name = __('Display columns table');
 $strSetupServers_user_desc = __('Leave empty if not using config auth');
 $strSetupServers_user_name = __('User for config auth');
 $strSetupServers_verbose_check_desc = __('Disable if you know that your pma_* tables are up to date. This prevents compatibility checks and thereby increases performance');
@@ -326,7 +326,7 @@ $strSetupServers_verbose_check_name = __('Verbose check');
 $strSetupServers_verbose_desc = __('A user-friendly description of this server. Leave blank to display the hostname instead.');
 $strSetupServers_verbose_name = __('Verbose name of this server');
 $strSetupSetValue = __('Set value: %s');
-$strSetupShowAll_desc = __('Whether a user should be displayed a "show all (records)" button');
+$strSetupShowAll_desc = __('Whether a user should be displayed a "show all (rows)" button');
 $strSetupShowAll_name = __('Allow to display all the rows');
 $strSetupShowChgPassword_desc = __('Please note that enabling this has no effect with [kbd]config[/kbd] authentication mode because the password is hard coded in the configuration file; this does not limit the ability to execute the same command directly');
 $strSetupShowChgPassword_name = __('Show password change form');
diff --git a/tbl_alter.php b/tbl_alter.php
index 4a2a208..92c9fed 100644
--- a/tbl_alter.php
+++ b/tbl_alter.php
@@ -1,7 +1,7 @@
 <?php
 /* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
- * Alter one or more table columns/fields
+ * Alter one or more table columns
  *
  * linked from table_structure, uses libraries/tbl_properties.inc.php to display
  * form and handles this form data
@@ -169,7 +169,7 @@ if ($abort == false) {
      */
     for ($i = 0; $i < $selected_cnt; $i++) {
         $_REQUEST['field'] = PMA_sqlAddslashes($selected[$i], true);
-        $result        = PMA_DBI_query('SHOW FULL FIELDS FROM ' . PMA_backquote($table) . ' FROM ' . PMA_backquote($db) . ' LIKE \'' . $_REQUEST['field'] . '\';');
+        $result        = PMA_DBI_query('SHOW FULL COLUMNS FROM ' . PMA_backquote($table) . ' FROM ' . PMA_backquote($db) . ' LIKE \'' . $_REQUEST['field'] . '\';');
         $fields_meta[] = PMA_DBI_fetch_assoc($result);
         PMA_DBI_free_result($result);
     }
diff --git a/tbl_change.php b/tbl_change.php
index 62fbbf1..7e32e9b 100644
--- a/tbl_change.php
+++ b/tbl_change.php
@@ -305,7 +305,7 @@ foreach ($rows as $row_id => $vrow) {
     <table>
     <thead>
         <tr>
-            <th><?php echo __('Field'); ?></th>
+            <th><?php echo __('Column'); ?></th>
 
  <?php
      if ($cfg['ShowFieldTypesInDataEditView']) {
@@ -725,7 +725,7 @@ foreach ($rows as $row_id => $vrow) {
             echo "\n";
             if (strlen($special_chars) > 32000) {
                 echo "        </td>\n";
-                echo '        <td>' . __(' Because of its length,<br /> this field might not be editable ');
+                echo '        <td>' . __(' Because of its length,<br /> this column might not be editable ');
             }
         } elseif ($field['pma_type'] == 'enum') {
             if (! isset($table_fields[$i]['values'])) {
diff --git a/tbl_indexes.php b/tbl_indexes.php
index 1d05e20..470cd04 100644
--- a/tbl_indexes.php
+++ b/tbl_indexes.php
@@ -186,7 +186,7 @@ PMA_Message::warning(__('("PRIMARY" <b>must</b> be the name of and <b>only of</b
 
 <table>
 <thead>
-<tr><th><?php echo __('Field'); ?></th>
+<tr><th><?php echo __('Column'); ?></th>
     <th><?php echo __('Size'); ?></th>
 </tr>
 </thead>
diff --git a/tbl_printview.php b/tbl_printview.php
index fc1c2bb..88c9a6b 100644
--- a/tbl_printview.php
+++ b/tbl_printview.php
@@ -139,7 +139,7 @@ foreach ($the_tables as $key => $table) {
 <table style="width: 100%;">
 <thead>
 <tr>
-    <th><?php echo __('Field'); ?></th>
+    <th><?php echo __('Column'); ?></th>
     <th><?php echo __('Type'); ?></th>
     <!--<th><?php echo __('Attributes'); ?></th>-->
     <th><?php echo __('Null'); ?></th>
diff --git a/tbl_relation.php b/tbl_relation.php
index c9dbc43..5ca5ed5 100644
--- a/tbl_relation.php
+++ b/tbl_relation.php
@@ -399,7 +399,7 @@ if ($col_rs && PMA_DBI_num_rows($col_rs) > 0) {
     <legend><?php echo __('Relations'); ?></legend>
 
     <table>
-    <tr><th><?php echo __('Field'); ?></th>
+    <tr><th><?php echo __('Column'); ?></th>
     <?php
     if ($cfgRelation['relwork']) {
         echo '<th>' . __('Internal relation');
@@ -545,7 +545,7 @@ if ($col_rs && PMA_DBI_num_rows($col_rs) > 0) {
         $disp = PMA_getDisplayField($db, $table);
         ?>
     <fieldset>
-        <label><?php echo __('Choose field to display') . ': '; ?></label>
+        <label><?php echo __('Choose column to display') . ': '; ?></label>
         <select name="display_field">
             <option value="">---</option>
         <?php
diff --git a/tbl_select.php b/tbl_select.php
index 67ff8a8..e965c50 100644
--- a/tbl_select.php
+++ b/tbl_select.php
@@ -132,7 +132,7 @@ while (list($operator) = each($GLOBALS['cfg']['UnaryOperators'])) {
     <legend><?php echo __('Do a "query by example" (wildcard: "%")') ?></legend>
     <table class="data">
     <thead>
-    <tr><th><?php echo __('Field'); ?></th>
+    <tr><th><?php echo __('Column'); ?></th>
         <th><?php echo __('Type'); ?></th>
         <th><?php echo __('Collation'); ?></th>
         <th><?php echo __('Operator'); ?></th>
@@ -267,7 +267,7 @@ $(function() {
     PMA_generate_slider_effect('searchoptions', __('Options'));
 ?>
 <fieldset id="fieldset_select_fields">
-    <legend><?php echo __('Select fields (at least one):'); ?></legend>
+    <legend><?php echo __('Select columns (at least one):'); ?></legend>
     <select name="param[]" size="<?php echo min($fields_cnt, 10); ?>"
         multiple="multiple">
     <?php
diff --git a/tbl_structure.php b/tbl_structure.php
index c255cde..f35032e 100644
--- a/tbl_structure.php
+++ b/tbl_structure.php
@@ -174,7 +174,7 @@ $i = 0;
 <tr>
     <th id="th<?php echo ++$i; ?>"></th>
     <th id="th<?php echo ++$i; ?>">#</th>
-    <th id="th<?php echo ++$i; ?>"><?php echo __('Field'); ?></th>
+    <th id="th<?php echo ++$i; ?>"><?php echo __('Column'); ?></th>
     <th id="th<?php echo ++$i; ?>"><?php echo __('Type'); ?></th>
     <th id="th<?php echo ++$i; ?>"><?php echo __('Collation'); ?></th>
     <th id="th<?php echo ++$i; ?>"><?php echo __('Attributes'); ?></th>
@@ -371,7 +371,7 @@ while ($row = PMA_DBI_fetch_assoc($fields_rs)) {
             <?php echo $titles['Change']; ?></a>
     </td>
     <td align="center">
-        <a href="sql.php?<?php echo $url_query; ?>&sql_query=<?php echo urlencode('ALTER TABLE ' . PMA_backquote($table) . ' DROP ' . PMA_backquote($row['Field'])); ?>&cpurge=1&purgekey=<?php echo urlencode($row['Field']); ?>&zero_rows=<?php echo urlencode(sprintf(__('Field %s has been dropped'), htmlspecialchars($row['Field']))); ?>"
+        <a href="sql.php?<?php echo $url_query; ?>&sql_query=<?php echo urlencode('ALTER TABLE ' . PMA_backquote($table) . ' DROP ' . PMA_backquote($row['Field'])); ?>&cpurge=1&purgekey=<?php echo urlencode($row['Field']); ?>&zero_rows=<?php echo urlencode(sprintf(__('Column %s has been dropped'), htmlspecialchars($row['Field']))); ?>"
             onclick="return confirmLink(this, 'ALTER TABLE <?php echo PMA_jsFormat($table); ?> DROP <?php echo PMA_jsFormat($row['Field']); ?>')">
             <?php echo $titles['Drop']; ?></a>
     </td>
@@ -533,13 +533,13 @@ if (! $tbl_is_view && ! $db_is_information_schema) {
 
     <br />
 <form method="post" action="tbl_addfield.php"
-    onsubmit="return checkFormElementInRange(this, 'num_fields', '<?php echo str_replace('\'', '\\\'', __('You have to add at least one field.')); ?>', 1)">
+    onsubmit="return checkFormElementInRange(this, 'num_fields', '<?php echo str_replace('\'', '\\\'', __('You have to add at least one column.')); ?>', 1)">
     <?php
     echo PMA_generate_common_hidden_inputs($db, $table);
     if ($cfg['PropertiesIconic']) {
-        echo '<img class="icon" src="' . $pmaThemeImage . 'b_insrow.png" width="16" height="16" alt="' . __('Add new field') . '"/>';
+        echo '<img class="icon" src="' . $pmaThemeImage . 'b_insrow.png" width="16" height="16" alt="' . __('Add field') . '"/>';
     }
-    echo sprintf(__('Add %s field(s)'), '<input type="text" name="num_fields" size="2" maxlength="2" value="1" onfocus="this.select()" />');
+    echo sprintf(__('Add %s column(s)'), '<input type="text" name="num_fields" size="2" maxlength="2" value="1" onfocus="this.select()" />');
 
     // I tried displaying the drop-down inside the label but with Firefox
     // the drop-down was blinking
diff --git a/tbl_tracking.php b/tbl_tracking.php
index 5f2b905..3e761f8 100644
--- a/tbl_tracking.php
+++ b/tbl_tracking.php
@@ -270,7 +270,7 @@ if (isset($_REQUEST['snapshot'])) {
     <table id="tablestructure" class="data">
     <thead>
     <tr>
-        <th><?php echo __('Field'); ?></th>
+        <th><?php echo __('Column'); ?></th>
         <th><?php echo __('Type'); ?></th>
         <th><?php echo __('Collation'); ?></th>
         <th><?php echo __('Null'); ?></th>
@@ -321,7 +321,7 @@ if (isset($_REQUEST['snapshot'])) {
             <th><?php echo __('Type');?></th>
             <th><?php echo __('Unique');?></th>
             <th><?php echo __('Packed');?></th>
-            <th><?php echo __('Field');?></th>
+            <th><?php echo __('Column');?></th>
             <th><?php echo __('Cardinality');?></th>
             <th><?php echo __('Collation');?></th>
             <th><?php echo __('Null');?></th>


hooks/post-receive
diff --git a/db_datadict.php b/db_datadict.php
index a38b35b..7af533c 100644
--- a/db_datadict.php
+++ b/db_datadict.php
@@ -125,9 +125,9 @@ while ($row = PMA_DBI_fetch_assoc($rowset)) {
 
 
     /**
      * Gets fields properties
      */
-    $result      = PMA_DBI_query('SHOW FIELDS FROM ' . PMA_backquote($table) . ';', null, PMA_DBI_QUERY_STORE);
+    $result      = PMA_DBI_query('SHOW COLUMNS FROM ' . PMA_backquote($table) . ';', null, PMA_DBI_QUERY_STORE);
     $fields_cnt  = PMA_DBI_num_rows($result);
 
     if (PMA_MYSQL_INT_VERSION < 50025) {
@@ -171,7 +171,7 @@ while ($row = PMA_DBI_fetch_assoc($rowset)) {
     ?>
 
 <table width="100%" class="print">
-<tr><th width="50"><?php echo __('Field'); ?></th>
+<tr><th width="50"><?php echo __('Column'); ?></th>
     <th width="80"><?php echo __('Type'); ?></th>
 <?php /*    <th width="50"><?php echo __('Attributes'); ?></th>*/ ?>
     <th width="40"><?php echo __('Null'); ?></th>
@@ -125,9 +125,9 @@ while ($row = PMA_DBI_fetch_assoc($rowset)) {
 
     /**
-     * Gets fields properties
+     * Gets columns properties
      */
-- 
phpMyAdmin




More information about the Git mailing list